@@ -247,9 +247,7 @@ gail_window_real_initialize (AtkObject *obj,
       name = gtk_widget_get_name (widget);
       if (name && !strcmp (name, "gtk-tooltips"))
         obj->role = ATK_ROLE_TOOL_TIP;
-      else if (GTK_IS_PLUG (widget))
-        obj->role = ATK_ROLE_PANEL;
-      else
+      else 
         obj->role = ATK_ROLE_FRAME;
     }
   else if (GTK_IS_HANDLE_BOX (widget))
